# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTIBILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

bl_info = {
    "name" : "Cloud Generator",
    "author" : "CGBlender", 
    "description" : "One-click transformation of meshes into realistic clouds",
    "blender" : (4, 2, 0),
    "version" : (2, 0, 0),
    "location" : "",
    "warning" : "",
    "doc_url": "", 
    "tracker_url": "", 
    "category" : "3D View" 
}


import bpy
import bpy.utils.previews
import os


addon_keymaps = {}
_icons = None
class SNA_PT_CLOUD_GENERATOR_C87DD(bpy.types.Panel):
    bl_label = 'cloud generator'
    bl_idname = 'SNA_PT_CLOUD_GENERATOR_C87DD'
    bl_space_type = 'VIEW_3D'
    bl_region_type = 'UI'
    bl_context = ''
    bl_category = 'CG'
    bl_order = 0
    bl_ui_units_x=0

    @classmethod
    def poll(cls, context):
        return not (False)

    def draw_header(self, context):
        layout = self.layout

    def draw(self, context):
        layout = self.layout
        op = layout.operator('sna.operator_3e6d5', text='Convert to clouds', icon_value=_icons['icon ccc.png'].icon_id, emboss=True, depress=False)
        layout.prop(bpy.context.view_layer.objects.active.modifiers['GeometryNodes'], '["Socket_2"]', text='Density', icon_value=0, emboss=True)
        layout.prop(bpy.context.view_layer.objects.active.modifiers['GeometryNodes'], '["Socket_3"]', text='Scale', icon_value=0, emboss=True)
        layout.prop(bpy.context.view_layer.objects.active.modifiers['GeometryNodes'], '["Socket_4"]', text='Density 2', icon_value=0, emboss=True)
        layout.prop(bpy.context.view_layer.objects.active.modifiers['GeometryNodes'], '["Socket_5"]', text='Scale 2', icon_value=0, emboss=True)
        layout.prop(bpy.context.view_layer.objects.active.modifiers['GeometryNodes'], '["Socket_6"]', text='V Density', icon_value=0, emboss=True)
        layout.prop(bpy.data.node_groups['Clouds G'].nodes['Set Material'].inputs[2], 'default_value', text='Material', icon_value=0, emboss=True)


class SNA_OT_Operator_3E6D5(bpy.types.Operator):
    bl_idname = "sna.operator_3e6d5"
    bl_label = "Operator"
    bl_description = ""
    bl_options = {"REGISTER", "UNDO"}

    @classmethod
    def poll(cls, context):
        if bpy.app.version >= (3, 0, 0) and False:
            cls.poll_message_set()
        return not False

    def execute(self, context):
        before_data = list(bpy.data.node_groups)
        bpy.ops.wm.append(directory=os.path.join(os.path.dirname(__file__), 'assets', 'Clouds .blend') + r'\NodeTree', filename='Clouds G', link=False)
        new_data = list(filter(lambda d: not d in before_data, list(bpy.data.node_groups)))
        appended_9B0EF = None if not new_data else new_data[0]
        bpy.ops.object.modifier_add(type='NODES')
        bpy.context.active_object.modifiers.active.node_group = bpy.data.node_groups['Clouds G']
        return {"FINISHED"}

    def invoke(self, context, event):
        return self.execute(context)


def register():
    global _icons
    _icons = bpy.utils.previews.new()
    bpy.utils.register_class(SNA_PT_CLOUD_GENERATOR_C87DD)
    if not 'icon ccc.png' in _icons: _icons.load('icon ccc.png', os.path.join(os.path.dirname(__file__), 'icons', 'icon ccc.png'), "IMAGE")
    bpy.utils.register_class(SNA_OT_Operator_3E6D5)


def unregister():
    global _icons
    bpy.utils.previews.remove(_icons)
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon
    for km, kmi in addon_keymaps.values():
        km.keymap_items.remove(kmi)
    addon_keymaps.clear()
    bpy.utils.unregister_class(SNA_PT_CLOUD_GENERATOR_C87DD)
    bpy.utils.unregister_class(SNA_OT_Operator_3E6D5)
